LocalBackendInitializer class

Public facade for creating a local artifact-host workspace.

Constructors

LocalBackendInitializer({LocalCliStateStore stateStore = const LocalCliStateStore(), String? templateRootPath})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

initialize(LocalBackendInitRequest request) Future<LocalBackendInitResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited