LocalBackendStatusResult class

Constructors

LocalBackendStatusResult({required LocalBackendState? state, required bool hasState, required bool processAlive, required bool healthy, int? healthStatusCode, String? healthError})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hasState bool
final
healthError String?
final
healthStatusCode int?
final
healthy bool
final
processAlive bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state LocalBackendState?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited