MiniProgramEmbeddingInitRequest class

Constructors

MiniProgramEmbeddingInitRequest({required String projectRootPath, String? repoRootPath, String? hostAppId, String? hostVersion, String nativeRoutePath = '/native/profile-editor', bool force = false})
const

Properties

force bool
final
hashCode int
The hash code for this object.
no setterinherited
hostAppId String?
final
hostVersion String?
final
nativeRoutePath String
final
projectRootPath String
final
repoRootPath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited