MiniProgramPreviewRequest class

Constructors

MiniProgramPreviewRequest({required String miniProgramId, required String miniProgramRootPath, required String deviceId, String? repoRootPath, String? mpBuildScriptPath})
const

Properties

deviceId String
final
hashCode int
The hash code for this object.
no setterinherited
miniProgramId String
final
miniProgramRootPath String
final
mpBuildScriptPath String?
final
repoRootPath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited