MiniProgramPublishRequest class

Constructors

MiniProgramPublishRequest({required String repoRootPath, String? backendRootPath, String? miniProgramId, String? miniProgramRootPath, String? mpBuildScriptPath, bool skipBuildPubGet = false})
const

Properties

backendRootPath String?
final
hashCode int
The hash code for this object.
no setterinherited
miniProgramId String?
final
miniProgramRootPath String?
final
mpBuildScriptPath String?
final
repoRootPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipBuildPubGet bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited