PublishedLocalArtifactRecord class

Constructors

PublishedLocalArtifactRecord({required String miniProgramId, required String version, required String latestManifestPath, required String versionedManifestPath, required String screensDirectoryPath, required String publishedAtUtc})
const
PublishedLocalArtifactRecord.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
latestManifestPath String
final
miniProgramId String
final
publishedAtUtc String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screensDirectoryPath String
final
version String
final
versionedManifestPath String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited